==> jc-1.4.0.tar.gz: java/net/URLClassLoader__24Resource.h <==
// abstract class java.net.URLClassLoader$Resource

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 9d385c5a860bc53d java_net_URLClassLoader__24Resource

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_net_URLClassLoader__24Resource_H_
#define _JC_java_net_URLClassLoader__24Resource_H_

// Forward structure declarations
struct _jc_java_io_InputStream$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_net_URL$object;
struct _jc_java_net_URLClassLoader__24URLLoader$object;
struct _jc_java_security_CodeSource$object;

// Typedefs
typedef struct _jc_java_net_URLClassLoader__24Resource$sub_refs	_jc_java_net_URLClassLoader__24Resource$sub_refs;
typedef struct _jc_java_net_URLClassLoader__24Resource$sub_nonrefs	_jc_java_net_URLClassLoader__24Resource$sub_nonrefs;
typedef struct _jc_java_net_URLClassLoader__24Resource$refs	_jc_java_net_URLClassLoader__24Resource$refs;
typedef struct _jc_java_net_URLClassLoader__24Resource$nonrefs	_jc_java_net_URLClassLoader__24Resource$nonrefs;
typedef struct _jc_java_net_URLClassLoader__24Resource$object	_jc_java_net_URLClassLoader__24Resource$object;

typedef const struct _jc_java_net_URLClassLoader__24Resource$vmethods	_jc_java_net_URLClassLoader__24Resource$vmethods;
typedef const struct _jc_java_net_URLClassLoader__24Resource$vtable	_jc_java_net_URLClassLoader__24Resource$vtable;
typedef const struct _jc_java_net_URLClassLoader__24Resource$vtype	_jc_java_net_URLClassLoader__24Resource$vtype;

// Constructors
extern void _jc_java_net_URLClassLoader__24Resource$method$_init$fadaca4c026c7161(_jc_env *, struct _jc_java_net_URLClassLoader__24Resource$object *, struct _jc_java_net_URLClassLoader__24URLLoader$object *, struct _jc_java_lang_String$object *);

// Virtual methods
extern _jc_object_array *_jc_java_net_URLClassLoader__24Resource$method$getCertificates$39b82b17735f6833(_jc_env *, struct _jc_java_net_URLClassLoader__24Resource$object *);
extern struct _jc_java_security_CodeSource$object *_jc_java_net_URLClassLoader__24Resource$method$getCodeSource$c5e8828ac4e55d4f(_jc_env *, struct _jc_java_net_URLClassLoader__24Resource$object *);
extern struct _jc_java_io_InputStream$object *_jc_java_net_URLClassLoader__24Resource$method$getInputStream$13cf75a12cabb343(_jc_env *, struct _jc_java_net_URLClassLoader__24Resource$object *);
extern jint _jc_java_net_URLClassLoader__24Resource$method$getLength$b9eaa8ec0a00f23d(_jc_env *, struct _jc_java_net_URLClassLoader__24Resource$object *);
extern struct _jc_java_net_URL$object *_jc_java_net_URLClassLoader__24Resource$method$getURL$f8efe3e882b98c02(_jc_env *, struct _jc_java_net_URLClassLoader__24Resource$object *);

// Virtual method descriptors
extern _jc_method _jc_java_net_URLClassLoader__24Resource$method_info$getCertificates$39b82b17735f6833;
extern _jc_method _jc_java_net_URLClassLoader__24Resource$method_info$getCodeSource$c5e8828ac4e55d4f;
extern _jc_method _jc_java_net_URLClassLoader__24Resource$method_info$getInputStream$13cf75a12cabb343;
extern _jc_method _jc_java_net_URLClassLoader__24Resource$method_info$getLength$b9eaa8ec0a00f23d;
extern _jc_method _jc_java_net_URLClassLoader__24Resource$method_info$getURL$f8efe3e882b98c02;

// Virtual methods structure
struct _jc_java_net_URLClassLoader__24Resource$vmethods {
	_jc_object_array	*(*getCertificates$39b82b17735f6833)(_jc_env *, struct _jc_java_net_URLClassLoader__24Resource$object *);
	struct _jc_java_security_CodeSource$object	*(*getCodeSource$c5e8828ac4e55d4f)(_jc_env *, struct _jc_java_net_URLClassLoader__24Resource$object *);
	struct _jc_java_io_InputStream$object	*(*getInputStream$13cf75a12cabb343)(_jc_env *, struct _jc_java_net_URLClassLoader__24Resource$object *);
	jint	(*getLength$b9eaa8ec0a00f23d)(_jc_env *, struct _jc_java_net_URLClassLoader__24Resource$object *);
	struct _jc_java_net_URL$object	*(*getURL$f8efe3e882b98c02)(_jc_env *, struct _jc_java_net_URLClassLoader__24Resource$object *);
};

// Vtable
struct _jc_java_net_URLClassLoader__24Resource$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_net_URLClassLoader__24Resource$vmethods	java_net_URLClassLoader__24Resource;
};

// Vtype
struct _jc_java_net_URLClassLoader__24Resource$vtype {
	_jc_type			type;
	_jc_java_net_URLClassLoader__24Resource$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_net_URLClassLoader__24Resource$sub_refs {
	struct _jc_java_net_URLClassLoader__24URLLoader$object	*loader;
	struct _jc_java_lang_String$object	*name;
};

// Reference instance fields (object)
struct _jc_java_net_URLClassLoader__24Resource$refs {
    _jc_java_net_URLClassLoader__24Resource$sub_refs	java_net_URLClassLoader__24Resource;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_net_URLClassLoader__24Resource$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_net_URLClassLoader__24Resource$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_net_URLClassLoader__24Resource$sub_nonrefs	java_net_URLClassLoader__24Resource;
};

// Object instance structure
struct _jc_java_net_URLClassLoader__24Resource$object {
	_jc_java_net_URLClassLoader__24Resource$refs	refs[0];
	_jc_word		lockword;
	_jc_java_net_URLClassLoader__24Resource$vtype	*vtype;
	_jc_java_net_URLClassLoader__24Resource$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_net_URLClassLoader__24Resource$vtype _jc_java_net_URLClassLoader__24Resource$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_net_URLClassLoader__24Resource, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_net_URLClassLoader__24Resource$class_object;

#endif	/* _JC_java_net_URLClassLoader__24Resource_H_ */

==> jc-1.4.6.tar.gz: java/net/URLClassLoader__24Resource.h <==
// abstract class java.net.URLClassLoader$Resource

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 9d385c5a860bc53d java_net_URLClassLoader__24Resource

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_net_URLClassLoader__24Resource_H_
#define _JC_java_net_URLClassLoader__24Resource_H_

// Forward structure declarations
struct _jc_java_io_InputStream$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_net_URL$object;
struct _jc_java_net_URLClassLoader__24URLLoader$object;
struct _jc_java_security_CodeSource$object;

// Typedefs
typedef struct _jc_java_net_URLClassLoader__24Resource$sub_refs	_jc_java_net_URLClassLoader__24Resource$sub_refs;
typedef struct _jc_java_net_URLClassLoader__24Resource$sub_nonrefs	_jc_java_net_URLClassLoader__24Resource$sub_nonrefs;
typedef struct _jc_java_net_URLClassLoader__24Resource$refs	_jc_java_net_URLClassLoader__24Resource$refs;
typedef struct _jc_java_net_URLClassLoader__24Resource$nonrefs	_jc_java_net_URLClassLoader__24Resource$nonrefs;
typedef struct _jc_java_net_URLClassLoader__24Resource$object	_jc_java_net_URLClassLoader__24Resource$object;

typedef const struct _jc_java_net_URLClassLoader__24Resource$vmethods	_jc_java_net_URLClassLoader__24Resource$vmethods;
typedef const struct _jc_java_net_URLClassLoader__24Resource$vtable	_jc_java_net_URLClassLoader__24Resource$vtable;
typedef const struct _jc_java_net_URLClassLoader__24Resource$vtype	_jc_java_net_URLClassLoader__24Resource$vtype;

// Constructors
extern void _jc_java_net_URLClassLoader__24Resource$method$_init$fadaca4c026c7161(_jc_env *, struct _jc_java_net_URLClassLoader__24Resource$object *, struct _jc_java_net_URLClassLoader__24URLLoader$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods
extern _jc_object_array *_jc_java_net_URLClassLoader__24Resource$method$getCertificates$39b82b17735f6833(_jc_env *, struct _jc_java_net_URLClassLoader__24Resource$object *) _JC_JCNI_ATTR;
extern struct _jc_java_security_CodeSource$object *_jc_java_net_URLClassLoader__24Resource$method$getCodeSource$c5e8828ac4e55d4f(_jc_env *, struct _jc_java_net_URLClassLoader__24Resource$object *) _JC_JCNI_ATTR;
extern struct _jc_java_io_InputStream$object *_jc_java_net_URLClassLoader__24Resource$method$getInputStream$13cf75a12cabb343(_jc_env *, struct _jc_java_net_URLClassLoader__24Resource$object *) _JC_JCNI_ATTR;
extern jint _jc_java_net_URLClassLoader__24Resource$method$getLength$b9eaa8ec0a00f23d(_jc_env *, struct _jc_java_net_URLClassLoader__24Resource$object *) _JC_JCNI_ATTR;
extern struct _jc_java_net_URL$object *_jc_java_net_URLClassLoader__24Resource$method$getURL$f8efe3e882b98c02(_jc_env *, struct _jc_java_net_URLClassLoader__24Resource$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_net_URLClassLoader__24Resource$method_info$getCertificates$39b82b17735f6833;
extern _jc_method _jc_java_net_URLClassLoader__24Resource$method_info$getCodeSource$c5e8828ac4e55d4f;
extern _jc_method _jc_java_net_URLClassLoader__24Resource$method_info$getInputStream$13cf75a12cabb343;
extern _jc_method _jc_java_net_URLClassLoader__24Resource$method_info$getLength$b9eaa8ec0a00f23d;
extern _jc_method _jc_java_net_URLClassLoader__24Resource$method_info$getURL$f8efe3e882b98c02;

// Virtual methods structure
struct _jc_java_net_URLClassLoader__24Resource$vmethods {
	_jc_object_array	*(*getCertificates$39b82b17735f6833)(_jc_env *, struct _jc_java_net_URLClassLoader__24Resource$object *) _JC_JCNI_ATTR;
	struct _jc_java_security_CodeSource$object	*(*getCodeSource$c5e8828ac4e55d4f)(_jc_env *, struct _jc_java_net_URLClassLoader__24Resource$object *) _JC_JCNI_ATTR;
	struct _jc_java_io_InputStream$object	*(*getInputStream$13cf75a12cabb343)(_jc_env *, struct _jc_java_net_URLClassLoader__24Resource$object *) _JC_JCNI_ATTR;
	jint	(*getLength$b9eaa8ec0a00f23d)(_jc_env *, struct _jc_java_net_URLClassLoader__24Resource$object *) _JC_JCNI_ATTR;
	struct _jc_java_net_URL$object	*(*getURL$f8efe3e882b98c02)(_jc_env *, struct _jc_java_net_URLClassLoader__24Resource$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_net_URLClassLoader__24Resource$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_net_URLClassLoader__24Resource$vmethods	java_net_URLClassLoader__24Resource;
};

// Vtype
struct _jc_java_net_URLClassLoader__24Resource$vtype {
	_jc_type			type;
	_jc_java_net_URLClassLoader__24Resource$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_net_URLClassLoader__24Resource$sub_refs {
	struct _jc_java_net_URLClassLoader__24URLLoader$object	*loader;
	struct _jc_java_lang_String$object	*name;
};

// Reference instance fields (object)
struct _jc_java_net_URLClassLoader__24Resource$refs {
    _jc_java_net_URLClassLoader__24Resource$sub_refs	java_net_URLClassLoader__24Resource;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_net_URLClassLoader__24Resource$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_net_URLClassLoader__24Resource$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_net_URLClassLoader__24Resource$sub_nonrefs	java_net_URLClassLoader__24Resource;
};

// Object instance structure
struct _jc_java_net_URLClassLoader__24Resource$object {
	_jc_java_net_URLClassLoader__24Resource$refs	refs[0];
	_jc_word		lockword;
	_jc_java_net_URLClassLoader__24Resource$vtype	*vtype;
	_jc_java_net_URLClassLoader__24Resource$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_net_URLClassLoader__24Resource$vtype _jc_java_net_URLClassLoader__24Resource$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_net_URLClassLoader__24Resource, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_net_URLClassLoader__24Resource$class_object;

#endif	/* _JC_java_net_URLClassLoader__24Resource_H_ */
